==> apache-tomcat-6.0.14-src.tar.gz: apache-tomcat-6.0.14-src/java/org/apache/catalina/ha/util/IDynamicProperty.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.catalina.ha.util;

import java.util.Iterator;

/**
 * @author Peter Rossbach
 * @version $Revision: 467222 $, $Date: 2006-10-24 05:17:11 +0200 (mar., 24 oct. 2006) $
 */

public interface IDynamicProperty {

    /**
     * set config attributes with reflect
     * 
     * @param name
     * @param value
     */
    public void setProperty(String name, Object value) ;

    /**
     * get current config
     * 
     * @param key
     * @return The property
     */
    public Object getProperty(String key) ;
    /**
     * Get all properties keys
     * 
     * @return An iterator over the property names
     */
    public Iterator getPropertyNames() ;

    /**
     * remove a configured property.
     * 
     * @param key
     */
    public void removeProperty(String key) ;

}

==> apache-tomcat-6.0.35-src.tar.gz: apache-tomcat-6.0.35-src/java/org/apache/catalina/ha/util/IDynamicProperty.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.catalina.ha.util;

import java.util.Iterator;

/**
 * @author Peter Rossbach
 * @version $Id: IDynamicProperty.java 939514 2010-04-29 23:55:14Z kkolinko $
 */

public interface IDynamicProperty {

    /**
     * set config attributes with reflect
     * 
     * @param name
     * @param value
     */
    public boolean setProperty(String name, Object value) ;

    /**
     * get current config
     * 
     * @param key
     * @return The property
     */
    public Object getProperty(String key) ;
    /**
     * Get all properties keys
     * 
     * @return An iterator over the property names
     */
    public Iterator getPropertyNames() ;

    /**
     * remove a configured property.
     * 
     * @param key
     */
    public void removeProperty(String key) ;

}
